meta_package_manager.managers.homebrew module — Meta Package Manager 2.4.0 documentation

# meta_package_manager.managers.homebrew module

class `meta_package_manager.managers.homebrew.` `Homebrew`

  Bases: `meta_package_manager.base.PackageManager`

  `cli_path` = u'/usr/local/bin/brew'
  `platforms` = frozenset([u'macos'])
  `requirement` = u'>= 1.0.*'
  `id` = u'brew'
  `get_version`()

    Fetch version from `brew --version` output.

  `sync`()
  `installed`

    The `cachedproperty` is used similar to `property`, except that the wrapped method is only called once. This is commonly used to implement lazy attributes.

    After the property has been accessed, the value is stored on the instance itself, using the same name as the cachedproperty. This allows the cache to be cleared with `delattr()`, or through manipulating the object’s `__dict__`.

  `outdated`

    The `cachedproperty` is used similar to `property`, except that the wrapped method is only called once. This is commonly used to implement lazy attributes.

    After the property has been accessed, the value is stored on the instance itself, using the same name as the cachedproperty. This allows the cache to be cleared with `delattr()`, or through manipulating the object’s `__dict__`.

  `upgrade_cli`(package_id=None)
  `upgrade_all_cli`()

class `meta_package_manager.managers.homebrew.` `HomebrewCask`

  Bases: `meta_package_manager.managers.homebrew.Homebrew`

  Cask is now part of Homebrew’s core and extend it.

  `cli_args` = [u'cask']
  `requirement` = u'>= 1.1.*'
  `id` = u'cask'
  `name` = u'Homebrew Cask'
  `sync`()
  `outdated`

    The `cachedproperty` is used similar to `property`, except that the wrapped method is only called once. This is commonly used to implement lazy attributes.

    After the property has been accessed, the value is stored on the instance itself, using the same name as the cachedproperty. This allows the cache to be cleared with `delattr()`, or through manipulating the object’s `__dict__`.

  `upgrade_cli`(package_id)

    Install a package.

    Todo

    Wait for https://github.com/caskroom/homebrew-cask/issues/22647 so we can force a cleanup in one go, as we do above with vanilla Homebrew.

  `upgrade_all_cli`()

    Cask has no way to upgrade all outdated packages.

    See: https://github.com/caskroom/homebrew-cask/issues/4678